.. role:: bash(code)
   :language: bash

Surveil
=======

Monitoring as a Service

An OpenStack related project designed to provide highly available, scalable
and flexible monitoring for OpenStack.

Project Info
############

* Documentation: https://surveil.readthedocs.org/
* IRC: #surveil at Freenode
* Issue tracker: https://waffle.io/surveil/surveil-meta (Also on `GitHub <https://github.com/surveil/surveil-meta/issues>`_)
* Open Gerrit Changesets: https://review.openstack.org/#/q/status:open+surveil,n,z

Related projects
----------------

* Bansho (Surveil Web UI): https://github.com/stackforge/bansho
* Puppet module: https://github.com/stackforge/puppet-surveil

Getting started
###############

There is a getting started guide available `here <https://surveil.readthedocs.org/tutorials/getting_started.html>`_.
